Overview
========

Collections in Plone are the most powerful tool content editors and site
managers have to construct navigation and site sections.

This is a brand new implementation of collections for Plone, using
ajax/javascript to make a simpler, easier and streamlined user experience
for using collections. Having a more lightweight backend that does not depend
on many nested criteria types.

It's designed with simplicity and usability as a main focus, so content editors
and site managers can create complex search queries with ease.
